@ECHO OFF

REM Change version numbers here:
SET PRODUCT_MAJOR_VERSION=8
SET PRODUCT_MINOR_VERSION=32
SET PRODUCT_MAINTENANCE_VERSION=0
SET PRODUCT_PATCH_VERSION=53

REM Configure available SDK version:
REM See folder e.g. "C:\Program Files (x86)\Windows Kits\[10]\bin\[10.0.17763.0]\x64\WiLangId.vbs"
SET WIN_SDK_MAJOR_VERSION=10
SET WIN_SDK_FULL_VERSION=10.0.17763.0

REM
REM Nothing below this line need to be changed normally.
REM

REM Cultures: https://msdn.microsoft.com/de-de/library/ee825488(v=cs.20).aspx
SET PRODUCT_SKU=skype
SET PRODUCT_VERSION=%PRODUCT_MAJOR_VERSION%.%PRODUCT_MINOR_VERSION%.%PRODUCT_MAINTENANCE_VERSION%.%PRODUCT_PATCH_VERSION%

REM Generate one ID per release. But do NOT use * as we need to keep the same number for all languages and platforms.
SETLOCAL ENABLEDELAYEDEXPANSION
FOR /F %%G IN ('POWERSHELL -COMMAND "$([guid]::NewGuid().ToString('b').ToUpper())"') DO ( 
  SET PRODUCT_ID=%%G
)

REM Generate platform specific builds (only x86 exists, but x64 may come in future)
FOR %%G IN (x86) DO (
  ECHO Generate Microsoft Skype setup for "%%G" platform
  ECHO ****************************************************
  SET CULTURE=en-us
  SET LANGIDS=1033
  SET PLATFORM=%%G
  SET SETUP_RESOURCES_DIR=.\Resources
  SET REPRO_DIR=.\SourceDir\!PRODUCT_VERSION!\!PLATFORM!\{app}
  SET OUTPUT_BASE_FILENAME=Skype-!PLATFORM!-!PRODUCT_VERSION!

  "!WIX!bin\heat.exe" dir "!REPRO_DIR!" -out Files-!OUTPUT_BASE_FILENAME!.wxs -gg -sfrag -scom -sreg -srd -ke -cg "AppFiles" -var var.ProductMajorVersion -var var.ProductMinorVersion -var var.ProductMaintenanceVersion -var var.ProductPatchVersion -var var.ReproDir -dr APPLICATIONFOLDER -platform !PLATFORM!
  "!WIX!bin\candle.exe" -arch !PLATFORM! Main.wxs Files-!OUTPUT_BASE_FILENAME!.wxs -ext WixUIExtension -ext WixUtilExtension -dProductMajorVersion="!PRODUCT_MAJOR_VERSION!" -dProductMinorVersion="!PRODUCT_MINOR_VERSION!" -dProductMaintenanceVersion="!PRODUCT_MAINTENANCE_VERSION!" -dProductPatchVersion="!PRODUCT_PATCH_VERSION!" -dProductId="!PRODUCT_ID!" -dReproDir="!REPRO_DIR!" -dSetupResourcesDir="!SETUP_RESOURCES_DIR!" -dCulture="!CULTURE!"
  "!WIX!bin\light.exe" Main.wixobj Files-!OUTPUT_BASE_FILENAME!.wixobj -ext WixUIExtension -ext WixUtilExtension -spdb -out "ReleaseDir\!OUTPUT_BASE_FILENAME!.!CULTURE!.msi" -loc "Lang\!PRODUCT_SKU!.!CULTURE!.wxl" -cultures:!CULTURE!


  COPY /Y "ReleaseDir\!OUTPUT_BASE_FILENAME!.en-us.msi" "ReleaseDir\!OUTPUT_BASE_FILENAME!.msi"

  REM Generate setup translations
  CALL BuildSetupTranslationTransform.cmd de-de 1031
  REM CALL BuildSetupTranslationTransform.cmd es-es 3082
  REM CALL BuildSetupTranslationTransform.cmd fr-fr 1036
  REM CALL BuildSetupTranslationTransform.cmd it-it 1040
  REM CALL BuildSetupTranslationTransform.cmd ja-jp 1041
  REM CALL BuildSetupTranslationTransform.cmd ko-kr 1042
  REM CALL BuildSetupTranslationTransform.cmd ru-ru 1049
  REM CALL BuildSetupTranslationTransform.cmd zh-cn 2052
  REM CALL BuildSetupTranslationTransform.cmd zh-tw 1028

  REM Add all supported languages to MSI Package attribute
  CSCRIPT "%ProgramFiles(x86)%\Windows Kits\%WIN_SDK_MAJOR_VERSION%\bin\%WIN_SDK_FULL_VERSION%\x64\WiLangId.vbs" ReleaseDir\!OUTPUT_BASE_FILENAME!.msi Package !LANGIDS!

  REM Dual-Signing with SHA-1/SHA-256 requires Win 8.1 SDK or later.
  REM "%ProgramFiles(x86)%\Windows Kits\%WIN_SDK_MAJOR_VERSION%\bin\%WIN_SDK_FULL_VERSION%\x64\signtool.exe" sign     -sha1 FingerPint-SHA1-Zertifikat   -fd sha1   -tr http://timestamp.geotrust.com -td sha1   "ReleaseDir\!OUTPUT_BASE_FILENAME!.en-us.msi"
  REM "%ProgramFiles(x86)%\Windows Kits\%WIN_SDK_MAJOR_VERSION%\bin\%WIN_SDK_FULL_VERSION%\x64\signtool.exe" sign -as -sha1 FingerPint-SHA256-Zertifikat -fd sha256 -tr http://timestamp.geotrust.com -td sha256 "ReleaseDir\!OUTPUT_BASE_FILENAME!.en-us.msi"
  REM "%ProgramFiles(x86)%\Windows Kits\%WIN_SDK_MAJOR_VERSION%\bin\%WIN_SDK_FULL_VERSION%\x64\signtool.exe" sign     -sha1 FingerPint-SHA1-Zertifikat   -fd sha1   -tr http://timestamp.geotrust.com -td sha1   "ReleaseDir\!OUTPUT_BASE_FILENAME!.msi"
  REM "%ProgramFiles(x86)%\Windows Kits\%WIN_SDK_MAJOR_VERSION%\bin\%WIN_SDK_FULL_VERSION%\x64\signtool.exe" sign -as -sha1 FingerPint-SHA256-Zertifikat -fd sha256 -tr http://timestamp.geotrust.com -td sha256 "ReleaseDir\!OUTPUT_BASE_FILENAME!.msi"

  REM Remove files we do not need any longer.
  DEL "Files-!OUTPUT_BASE_FILENAME!.wxs"
  DEL "Files-!OUTPUT_BASE_FILENAME!.wixobj"
)
ENDLOCAL

REM Cleanup variables
SET CULTURE=
SET LANGIDS=
SET PRODUCT_SKU=
SET WIN_SDK_MAJOR_VERSION=
SET WIN_SDK_FULL_VERSION=
SET PRODUCT_MAJOR_VERSION=
SET PRODUCT_MINOR_VERSION=
SET PRODUCT_MAINTENANCE_VERSION=
SET PRODUCT_PATCH_VERSION=
SET PRODUCT_ID=
SET PRODUCT_VERSION=
SET PLATFORM=
SET SETUP_RESOURCES_DIR=
SET REPRO_DIR=
SET OUTPUT_BASE_FILENAME=
